'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _Shared = require('../../Shared');

var _Shared2 = _interopRequireDefault(_Shared);

var _reactWidgets = require('coreui-deps/lib/react-widgets');

var _reactWidgets2 = _interopRequireDefault(_reactWidgets);

var _DateTimePickerInput = require('../../theme/components/DateTimePickerInput');

var _DateTimePickerInput2 = _interopRequireDefault(_DateTimePickerInput);

var _dedupe = require('classnames/dedupe');

var _dedupe2 = _interopRequireDefault(_dedupe);

var _mapProps = require('recompose/mapProps');

var _mapProps2 = _interopRequireDefault(_mapProps);

var _ramda = require('ramda');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

var RWDateTimePicker = _reactWidgets2.default.DateTimePicker;

var systemStyles = {};

var DateTimePickerInputContainer = (0, _mapProps2.default)(function (_ref) {
  var className = _ref.className,
      sheet = _ref.sheet,
      style = _ref.style,
      theme = _ref.theme,
      rest = _objectWithoutProperties(_ref, ['className', 'sheet', 'style', 'theme']);

  return _extends({
    className: (0, _dedupe2.default)(sheet.classes.dateTimePickerInput, theme.classes.dateTimePickerInput, className),
    style: (0, _ramda.merge)(theme.styles.dateTimePickerInput, style)
  }, rest);
})(RWDateTimePicker);

var StyledDateTimePickerInput = _Shared2.default.injectSheet(systemStyles)(DateTimePickerInputContainer);

/**
 * You must configure a localizer to use this component!
 * Manipulate different parts of a JavaScript Date object with ease. Date formats are highly localized, and localization is hard, rather than provide a half baked solution, coreui requires that you specify a *localizer* in order for the widget to work. You can read more about localizers here: [localization](http://jquense.github.io/react-widgets/docs/#/i18n).
 * Dates are never mutated but always return and operate on a new Date instance. When the `date` prop is used the DateTimePickerInput will pass through the relevant props to the Calendar Widget and Calendar keyboard navigation keys will also work.
 */
var DateTimePickerInput = function DateTimePickerInput(props) {
  return _react2.default.createElement(
    StyledDateTimePickerInput,
    props,
    props.children
  );
};

var classes = _DateTimePickerInput2.default.classes;
var options = _DateTimePickerInput2.default.options;
var styles = _DateTimePickerInput2.default.styles;

DateTimePickerInput.defaultProps = {
  calendar: true,
  duration: 250,
  finalView: 'century',
  footer: false,
  initialView: 'month',
  isRtl: false,
  max: new Date(2099, 11, 31),
  messages: { calendarButton: 'Select Date', timeButton: 'Select Time' },
  min: new Date(1900, 0, 1),
  step: 30,
  theme: { classes: classes, options: options, styles: styles },
  time: true
};

DateTimePickerInput.displayName = 'DateTimePickerInput';

DateTimePickerInput.propTypes = {
  'aria-labelledby': _react.PropTypes.string,
  autoFocus: _react.PropTypes.bool,
  /**
   * Whether to show the date picker button.
   */
  calendar: _react.PropTypes.bool,
  /**
   * A formatter for century, the default formats the first and last year of the century like: 1900 - 1999.
   */
  centuryFormat: _react.PropTypes.string,
  children: _react.PropTypes.node,
  culture: _react.PropTypes.string,
  /**
   * Default current date at which the calendar opens. If none is provided, opens at today's date or the `value` date (if any).
   */
  currentDate: _react.PropTypes.instanceOf(Date),
  /**
   * A formatter for day of the month
   */
  dateFormat: _react.PropTypes.string,
  /**
   * Provide a custom component to render the days of the month. The Component is provided the following props
   * - `date`: a `Date` object for the day of the month to render
   * - `label`: a formatted `String` of the date to render. To adjust the format of the `label` string use the `dateFormat` prop, listed below.
   */
  dayComponent: _react.PropTypes.element,
  /**
   * A formatter calendar days of the week, the default formats each day as a Narrow name: "Mo", "Tu", etc.
   */
  dayFormat: _react.PropTypes.string,
  /**
   * A formatter for decade, the default formats the first and last year of the decade like: 2000 - 2009.
   */
  decadeFormat: _react.PropTypes.string,
  disabled: _react.PropTypes.oneOfType([_react.PropTypes.bool, _react.PropTypes.array]),
  /**
   * The highest level view the calendar can navigate up to. This value should be higher than `initialView`
   * Acceptable values are: `"month"` `"year"` `"decade"` `"century"`
   */
  dropUp: _react.PropTypes.bool,
  /**
   * The speed, in milliseconds, of the either dropdown animation.
   */
  duration: _react.PropTypes.number,
  /**
   * A string format to be used while the date input has focus. Useful for showing a simpler format for inputting. For more information about formats visit the [Localization page](i18n)
   */
  editFormat: _react.PropTypes.string,
  /**
   * The highest level view the calendar can navigate up to. This value should be higher than `initialView`
   * Acceptable values are: `"month"` `"year"` `"decade"` `"century"`
   */
  finalView: _react.PropTypes.string,
  /**
   * Show or hide the Calendar footer.
   */
  footer: _react.PropTypes.bool,
  /**
   * A formatter for the Calendar footer, formats Today's Date as a string.
   */
  footerFormat: _react.PropTypes.string,
  /**
   * A string format used to display the date value. For more information about formats visit the [Localization page](i18n)
   */
  format: _react.PropTypes.string,
  /**
   * A formatter for the header button of the month view
   */
  headerFormat: _react.PropTypes.string,
  /**
   * The starting and lowest level view the calendar can navigate down to.
   * Acceptable values are: `"month"` `"year"` `"decade"` `"century"`
   */
  initialView: _react.PropTypes.string,
  /**
   * mark whether the widget should render right-to-left. This property can also be implicitly passed to the widget through a `childContext` prop (`isRtl`) this allows higher level application components to specify the direction.
   */
  isRtl: _react.PropTypes.bool,
  /**
   * The maximum Date that can be selected. Max only limits selection, it doesn't constrain the date values that can be typed or pasted into the widget. If you need this behavior you can constrain values via the `onChange` handler.
   */
  max: _react.PropTypes.instanceOf(Date),
  /**
   * Object hash containing display text and/or text for screen readers. Use the `messages` object to localize widget text and increase accessibility.
   */
  messages: _react.PropTypes.shape({
    /**
     * title and screen reader text for the left arrow button.
     */
    calendarButton: _react.PropTypes.string,
    /**
     * title and screen reader text for the right arrow button.
     */
    timeButton: _react.PropTypes.string
  }),
  /**
   * The minimum Date that can be selected. Min only limits selection, it doesn't constrain the date values that can be typed or pasted into the widget. If you need this behavior you can constrain values via the `onChange` handler.
   */
  min: _react.PropTypes.instanceOf(Date),
  /**
   * A formatter for month name.
   */
  monthFormat: _react.PropTypes.string,
  /**
   * Change event Handler that is called when the value is changed. The handler is called with the Date object
   */
  name: _react.PropTypes.string,
  /**
   * change event Handler that is called when the value is changed. The handler is called with both the current `Date` object (or null if it was not parseable), and the second argument is a `string` representation of the date value, formated by the `format` prop.
   */
  onChange: _react.PropTypes.func,
  /**
   * Change event Handler that is called when the currentDate is changed. The handler is called with the currentDate object
   */
  onCurrentDateChange: _react.PropTypes.func,
  /**
   * Callback fired when the Calendar navigates between views, or forward and backwards in time.
   */
  onNavigate: _react.PropTypes.func,
  /**
   * Whether or not the DateTimePickerInput is open. When unset (`undefined`) the DateTimePickerInput will handle the opening and closing internally. The `defaultOpen` prop can be used to set an initialization value for uncontrolled widgets.
   * Acceptable values are: `false` `"calendar"` `"time"`
   */
  open: _react.PropTypes.oneOfType([_react.PropTypes.bool, _react.PropTypes.string]),
  /**
   * This handler fires when an item has been selected from the list or calendar. It fires before the `onChange` handler, and fires regardless of whether the value has actually changed.
   */
  onSelect: _react.PropTypes.func,
  /**
   * Called when the DateTimePickerInput is about to open or close. `onToggle` should be used when the `open` prop is set otherwise the widget will never open or close.
   */
  onToggle: _react.PropTypes.func,
  /**
   * Determines how the widget parses the typed date string into a Date object. You can provide an array of formats to try, or provide a function that returns a date to handle parsing yourself. When `parse` is unspecified and the `format` prop is a `String` parse will automatically use that format as its default
   */
  parse: _react.PropTypes.oneOfType([_react.PropTypes.arrayOf(_react.PropTypes.string), _react.PropTypes.string, _react.PropTypes.func]),
  placeholder: _react.PropTypes.string,
  readOnly: _react.PropTypes.oneOfType([_react.PropTypes.bool, _react.PropTypes.array]),
  /**
   * The amount of minutes between each entry in the time list.
   */
  step: _react.PropTypes.number,

  theme: _react.PropTypes.oneOfType([_react.PropTypes.bool, _react.PropTypes.object]),
  /**
   * Whether to show the time picker button.
   */
  time: _react.PropTypes.bool,

  timeComponent: _react.PropTypes.element,
  /**
   * A string format used by the time dropdown to render times. For more information about formats visit the [Localization page](i18n)
   */
  timeFormat: _react.PropTypes.string,
  /**
   * The current selected date, should be a `Date` instance or `null`.
   */
  value: _react.PropTypes.instanceOf(Date),
  /**
   * A formatter for the year.
   */
  yearFormat: _react.PropTypes.string
};

_Shared2.default.registerComponent('DateTimePickerInput', DateTimePickerInput);

exports.default = DateTimePickerInput;