import { create as createJss } from 'jss';
import preset from 'jss-preset-default';
import { create as createInjectSheet } from 'react-jss';
import reactWidgetsSheet from './jss/react-widgets';
import apolloWidgetsSheet from './jss/apollo-widgets';

class Shared {
  constructor() {
    this.importedComponents = {};

    this.jss = createJss();
    this.injectSheet = createInjectSheet(this.jss);
    this.jss.setup(preset());

    // temporary instance for react-widgets sheet to workaround css-vendor content escaping issues
    // this.rwjss = create();

    this.attachReactWidgetsSheet();
    this.attachApolloWidgetsSheet();
  }

  attachReactWidgetsSheet = () => {
    this.jss.createStyleSheet(reactWidgetsSheet, { named: false }).attach();
  }

  attachApolloWidgetsSheet = () => {
    this.jss.createStyleSheet(apolloWidgetsSheet, { named: false }).attach();
  }

  getRegisteredComponents = () => this.importedComponents;

  registerComponent = (name, component) => {
    this.importedComponents[name] = component;
  }
}

const SharedInst = new Shared();

export default SharedInst;
